VaultClient

Struct VaultClient 

pub struct VaultClient { /* private fields */ }
An asynchronous Vault client

Build instances with ClientBuilder

Implementations

Source

impl VaultClient

pub fn new(address: &str, token: &str) -> Result<Self, VaultError>

Create a client with an address and plaintext token

For more options, use VaultClient::builder()

pub fn from_env() -> Result<Self, VaultError>

Create a client from VAULT_* environment variables; token resolution order: VAULT_TOKEN~/.vault-tokenNone

pub fn builder() -> ClientBuilder

pub fn cubbyhole(&self, mount: &str) -> CubbyholeHandler<'_>

pub fn kv1(&self, mount: &str) -> Kv1Handler<'_>

pub fn kv2(&self, mount: &str) -> Kv2Handler<'_>

pub fn transit(&self, mount: &str) -> TransitHandler<'_>

pub fn pki(&self, mount: &str) -> PkiHandler<'_>

pub fn database(&self, mount: &str) -> DatabaseHandler<'_>

pub fn ssh(&self, mount: &str) -> SshHandler<'_>

pub fn aws_secrets(&self, mount: &str) -> AwsSecretsHandler<'_>

pub fn totp(&self, mount: &str) -> TotpHandler<'_>

pub fn consul_secrets(&self, mount: &str) -> ConsulHandler<'_>

pub fn nomad_secrets(&self, mount: &str) -> NomadHandler<'_>

pub fn azure_secrets(&self, mount: &str) -> AzureHandler<'_>

pub fn gcp_secrets(&self, mount: &str) -> GcpHandler<'_>

pub fn rabbitmq(&self, mount: &str) -> RabbitmqHandler<'_>

pub fn terraform_cloud(&self, mount: &str) -> TerraformCloudHandler<'_>

pub fn identity(&self) -> IdentityHandler<'_>

pub fn sys(&self) -> SysHandler<'_>

pub fn auth(&self) -> AuthHandler<'_>

pub fn set_token(&self, token: SecretString) -> Result<(), VaultError>

Replace the current token at runtime

pub fn with_namespace(&self, ns: &str) -> Self

Return a client view with a different namespace (cheap Arc clone)

pub fn with_wrap_ttl(&self, ttl: &str) -> Self

Return a client view with a different wrap TTL (cheap Arc clone)

Source

impl VaultClient

pub async fn read<T: DeserializeOwned>( &self, path: &str, ) -> Result<T, VaultError>

Read from an arbitrary Vault path, deserializing the data field

pub async fn read_raw( &self, path: &str, ) -> Result<VaultResponse<Value>, VaultError>

Read from an arbitrary path, returning the full Vault response envelope

pub async fn write<T: DeserializeOwned>( &self, path: &str, data: &impl Serialize, ) -> Result<VaultResponse<T>, VaultError>

Write to an arbitrary Vault path

pub async fn delete(&self, path: &str) -> Result<(), VaultError>

Delete at an arbitrary Vault path

pub async fn list(&self, path: &str) -> Result<Vec<String>, VaultError>

List keys at an arbitrary Vault path